@@ -22,6 +22,14 @@ sub makemaker_args {
     $args;
 }
 
+sub build_subdirs {
+    my $self = shift;
+    my $subdirs = $self->makemaker_args->{DIR} ||= [];
+    for my $subdir (@_) {
+        push @$subdirs, $subdir;
+    }
+}
+
 sub clean_files {
     my $self = shift;
     my $clean = $self->makemaker_args->{clean} ||= {};
@@ -52,7 +60,11 @@ sub write {
     $args->{NAME} = $self->module_name || $self->name || $self->determine_NAME($args);
     $args->{VERSION} = $self->version || $self->determine_VERSION($args);
     $args->{NAME} =~ s/-/::/g;
-    $args->{test} = {TESTS => $self->tests};
+
+    # Only call $self->tests if we haven't been given explicit
+    # tests from makemaker_args.
+    $args->{test} ||= {TESTS => $self->tests};
+
 
     if ($] >= 5.005) {
 	$args->{ABSTRACT} = $self->abstract;
